==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/PrinterErrorReducer.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {
  PrinterErrorAddErrorAction,
  PrinterErrorMarkSeenAction,
  PrinterErrorUpdateErrorAction
} from "../actions/PrinterErrorAction";
import type {
  PrinterErrorState
} from "../state/RepetierState";
import {Action, createReducer, on} from "@ngrx/store";

const reducer = createReducer({},
  on(PrinterErrorAddErrorAction, (state, payload) => {
    const m: any = {};
    m[payload.id] = payload;
    return Object.assign({}, state, m);
  }),
  on(PrinterErrorUpdateErrorAction, (state, payload) => {
    const m: any = {};
    m[payload.id] = Object.assign({}, state[payload.id], payload.error);
    return Object.assign({}, state, m);
  }),
  on(PrinterErrorMarkSeenAction, (state, payload) => {
    const m: any = {};
    m[payload.id] = Object.assign({}, state[payload.id], {seen: true});
    return Object.assign({}, state, m);
  })
);

export function PrinterErrorReducer(state: { [key: string]: PrinterErrorState } | undefined, action: Action) {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("PrinterErrorsReducer error", e);
    return state;
  }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/PrinterErrorReducer.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {
  PrinterErrorAddErrorAction,
  PrinterErrorMarkSeenAction,
  PrinterErrorUpdateErrorAction
} from "../actions/PrinterErrorAction";
import type {
  PrinterErrorState
} from "../state/RepetierState";
import {Action, createReducer, on} from "@ngrx/store";

const reducer = createReducer({},
  on(PrinterErrorAddErrorAction, (state, payload) => {
    const m: any = {};
    m[payload.id] =  JSON.parse(JSON.stringify(payload));
    return Object.assign({}, state, m);
  }),
  on(PrinterErrorUpdateErrorAction, (state, payload) => {
    const m: any = {};
    m[payload.id] = Object.assign({}, state[payload.id], payload.error);
    return Object.assign({}, state, m);
  }),
  on(PrinterErrorMarkSeenAction, (state, payload) => {
    const m: any = {};
    m[payload.id] = Object.assign({}, state[payload.id], {seen: true});
    return Object.assign({}, state, m);
  })
);

export function PrinterErrorReducer(state: { [key: string]: PrinterErrorState } | undefined, action: Action) {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("PrinterErrorsReducer error", e);
    return state;
  }
}
